@@ -701,6 +701,17 @@ class GTK_Main(object):
         menu_play_headset.set_active(settings.play_on_headset)
         menu.append(menu_play_headset)
 
+        def fmtx_settings(button):
+            import osso
+            ctx = osso.Context('Panucci', '1.3.3.7', False)
+            plugin = osso.Plugin(ctx)
+            plugin.plugin_execute('libcpfmtx.so', True)
+
+	menu_fmtx = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+	menu_fmtx.set_text(_('FM transmitter'), '')
+        menu_fmtx.connect('clicked', fmtx_settings)
+        menu.append(menu_fmtx)
+
 	menu_about = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
 	menu_about.set_text(_('About Panucci'), '')
         menu_about.connect('clicked', self.show_about, self.main_window)
